package httpserver

import (
	"os"
	"testing"
	"time"

	"github.com/it-novum/nsta/gearman"
	"github.com/it-novum/nsta/httpproto"
	"github.com/it-novum/nsta/satstatus"
)

type TestSatIO struct {
	satid   int
	satname string
	apikey  string
}

func (s *TestSatIO) SatelliteID() int {
	return s.satid
}

func (s *TestSatIO) SatelliteName() string {
	return s.satname
}

func (s *TestSatIO) APIKey() string {
	return s.apikey
}

func (s *TestSatIO) Incoming(*gearman.Message) {
	return
}

func (s *TestSatIO) Outgoing() []*gearman.Message {
	return []*gearman.Message{}
}

func (s *TestSatIO) LastExport() time.Time {
	return time.Now()
}

func (s *TestSatIO) Export(_ *httpproto.ExportData) error {
	return nil
}

func (s *TestSatIO) WebStatus(_ *satstatus.Status) {
}

func TestHTTPServerMaster(t *testing.T) {
	io := &TestSatIO{
		satid:   1,
		satname: "test",
		apikey:  "test",
	}

	srv := New(os.Stdout, "/opt/openitc/nagios", "127.0.0.1:6122", "127.0.0.1:6123", "/etc/ssl/certs/ssl-cert-snakeoil.pem", "/etc/ssl/private/ssl-cert-snakeoil.key", WebserverTypeMaster)
	srv.RegisterSatelliteIO(io)
	srv.UnregisterSatelliteIO(io.satid)
	srv.Stop()
}

func TestHTTPServerSatellite(t *testing.T) {
	io := &TestSatIO{
		satid:   1,
		satname: "test",
		apikey:  "test",
	}

	srv := New(os.Stdout, "/opt/openitc/nagios", "127.0.0.1:6122", "127.0.0.1:6123", "/etc/ssl/certs/ssl-cert-snakeoil.pem", "/etc/ssl/private/ssl-cert-snakeoil.key", WebserverTypeSatellite)
	srv.RegisterSatelliteIO(io)
	srv.UnregisterSatelliteIO(io.satid)
	srv.Stop()
}
